@@ -3,7 +3,6 @@
 import json
 import logging
 import random
-import tempfile
 import uuid
 
 from cached_property import cached_property
@@ -20,13 +19,11 @@ from requests.exceptions import RequestException
 logger = logging.getLogger(__file__)
 
 DRIVER_MAP = {
-    "phantomjs": webdriver.PhantomJS,
     "firefox": webdriver.Firefox,
     "chrome": webdriver.Chrome,
     "chrome_headless": webdriver.Chrome,
 }
 CAPABILITY_MAP = {
-    "phantomjs": webdriver.DesiredCapabilities.PHANTOMJS,
     "firefox": webdriver.DesiredCapabilities.FIREFOX,
     "chrome": webdriver.DesiredCapabilities.CHROME,
     "chrome_headless": webdriver.DesiredCapabilities.CHROME,
@@ -93,13 +90,7 @@ class BotBase(object):
             driver_class = DRIVER_MAP.get(driver_type.lower())
             if driver_class is not None:
                 kwargs = {}
-                # Phantom JS needs a new local storage directory for every run
-                if driver_class is webdriver.PhantomJS:
-                    tmpdirname = tempfile.mkdtemp()
-                    kwargs = {
-                        "service_args": ["--local-storage-path={}".format(tmpdirname)],
-                    }
-                elif driver_type.lower() == "chrome_headless":
+                if driver_type.lower() == "chrome_headless":
                     from selenium.webdriver.chrome.options import Options
 
                     chrome_options = Options()
