@@ -331,14 +331,14 @@ def deploy(mode, server, dns_host, config_options, archive_path):  # pragma: no
     )
     print("Cleaning up db/user")
     executor.run(
-        fr"""docker-compose -f ~/dallinger/docker-compose.yml exec -T postgresql psql -U dallinger -c 'DROP DATABASE IF EXISTS "{experiment_id}";'"""
+        rf"""docker-compose -f ~/dallinger/docker-compose.yml exec -T postgresql psql -U dallinger -c 'DROP DATABASE IF EXISTS "{experiment_id}";'"""
     )
     executor.run(
-        fr"""docker-compose -f ~/dallinger/docker-compose.yml exec -T postgresql psql -U dallinger -c 'DROP USER IF EXISTS "{experiment_id}"; '"""
+        rf"""docker-compose -f ~/dallinger/docker-compose.yml exec -T postgresql psql -U dallinger -c 'DROP USER IF EXISTS "{experiment_id}"; '"""
     )
     print(f"Creating database {experiment_id}")
     executor.run(
-        fr"""docker-compose -f ~/dallinger/docker-compose.yml exec -T postgresql psql -U dallinger -c 'CREATE DATABASE "{experiment_id}"'"""
+        rf"""docker-compose -f ~/dallinger/docker-compose.yml exec -T postgresql psql -U dallinger -c 'CREATE DATABASE "{experiment_id}"'"""
     )
     create_user_script = f"""CREATE USER "{experiment_id}" with encrypted password '{postgresql_password}'"""
     executor.run(
@@ -390,13 +390,16 @@ def deploy(mode, server, dns_host, config_options, archive_path):  # pragma: no
     )
     print(response.json()["recruitment_msg"])
 
-    print("To display the logs for this experiment you can run:")
-    print(
-        f"ssh {ssh_user}@{ssh_host} docker-compose -f '~/dallinger/{experiment_id}/docker-compose.yml' logs -f"
-    )
-    print(
-        f"You can now log in to the console at https://{experiment_id}.{dns_host}/dashboard as user {cfg['ADMIN_USER']} using password {cfg['dashboard_password']}"
-    )
+    deployment_infos = [
+        "To display the logs for this experiment you can run:",
+        f"ssh {ssh_user}@{ssh_host} docker-compose -f '~/dallinger/{experiment_id}/docker-compose.yml' logs -f",
+        f"You can now log in to the console at https://{experiment_id}.{dns_host}/dashboard as user {cfg['ADMIN_USER']} using password {cfg['dashboard_password']}",
+    ]
+    for line in deployment_infos:
+        print(line)
+    with open(f"deployment-info_{experiment_id}.txt", "w") as f:
+        for line in deployment_infos:
+            f.write(f"{line}\n")
 
 
 def get_experiment_id_from_archive(archive_path):
@@ -569,10 +572,10 @@ class Executor:
         status = channel.recv_exit_status()
         if raise_ and status != 0:
             print(f"Error: exit code was not 0 ({status})")
-            print(channel.recv(10 ** 10).decode())
-            print(channel.recv_stderr(10 ** 10).decode())
+            print(channel.recv(10**10).decode())
+            print(channel.recv_stderr(10**10).decode())
             raise ExecuteException
-        return channel.recv(10 ** 10).decode()
+        return channel.recv(10**10).decode()
 
     def check_sudo(self):
         """Make sure the current user is authorized to invoke sudo without providing a password.
